@@ -32,7 +32,7 @@ def make_aware(value, timezone):
     """
     Makes a naive datetime.datetime in a given time zone aware.
     """
-    if hasattr(timezone, 'localize'):
+    if hasattr(timezone, 'localize') and value not in (datetime.datetime.min, datetime.datetime.max):
         # available for pytz time zones
         return timezone.localize(value, is_dst=None)
     else:
